import { tripInfoType } from "./TripClass";
import prisma from "./prisma";
import { Redis } from "ioredis";

const onMessage = async (_channel: string, string: string) => {
  const data: tripInfoType = JSON.parse(string);
  const ritId = data.ritId;
  const date = data.date;
  const firstTime = data.firstTime;
  const vehiclesJson = data.stationInfo
    .flatMap((station) => station.vehicles)
    .filter((item) => item)
    .map((item) => JSON.stringify(item));
  const vehicles = [...new Set(vehiclesJson)]
    .map(
      (item) => JSON.parse(item) as (typeof data.stationInfo)[0]["vehicles"][0],
    )
    .map((vehicle) => ({
      number: vehicle.vehicleId,
      type: vehicle.type,
    }));
  try {
    await prisma.$transaction([
      prisma.ns_rit.deleteMany({
        where: {
          ritId,
          date,
        },
      }),
      prisma.ns_rit.create({
        data: {
          ritId,
          date,
          firstTime,
          vehicles: {
            connectOrCreate: vehicles.map((vehicle) => ({
              where: {
                number_type: {
                  number: vehicle.number,
                  type: vehicle.type,
                },
              },
              create: {
                number: vehicle.number,
                type: vehicle.type,
              },
            })),
          },
        },
      }),
    ]);
  } catch (e) {
    console.log(e);
    console.dir(vehicles, { depth: null });
    throw new Error("Error saving to db");
  }
};

export async function startListener(redisUrl: string) {
  const subscriber = new Redis(redisUrl);
  subscriber.subscribe("nsRit");
  subscriber.on("message", onMessage);
}
