import express from "express";
import prisma from "./prisma";

export async function startServer() {
  const app = express();

  app.get("/:date/:nsRitId", async (req, res) => {
    const { date, nsRitId } = req.params;
    console.log(req.params);
    const rit = await prisma.ns_rit.findUnique({
      where: {
        ritId_date: {
          ritId: +nsRitId,
          date: +date,
        },
      },
      select: {
        vehicles: {
          select: {
            nsRit: {
              select: {
                ritId: true,
                date: true,
                firstTime: true,
              },
            },
          },
        },
      },
    });
    if (!rit) return res.status(404).end("Not found");
    let ritten = rit.vehicles.flatMap((item) => item.nsRit);
    //remove duplicates
    ritten = [...new Set(ritten.map((rit) => JSON.stringify(rit)))].map(
      (item) => JSON.parse(item),
    );
    //sort ritten by date then firstTIme (AI GENERATED!)
    ritten.sort((a, b) => {
      if (a.date < b.date) return -1;
      if (a.date > b.date) return 1;
      if (a.firstTime < b.firstTime) return -1;
      if (a.firstTime > b.firstTime) return 1;
      return 0;
    });
    res.json(ritten);
  });

  app.listen(3002, () => {
    console.log("Listening on port 3002!");
  });
}
